@@ -6,7 +6,8 @@
 #include <pbcopper/PbcopperConfig.h>
 
 #include <cstdint>
-#include <ostream>
+
+#include <iosfwd>
 #include <string>
 #include <vector>
 
@@ -74,7 +75,7 @@ public:
 
     QualityValues() = default;
 
-    QualityValues& operator=(std::vector<QualityValue> quals);
+    QualityValues& operator=(std::vector<QualityValue> quals) noexcept;
 
     /// \}
 
@@ -82,8 +83,8 @@ public:
     /// \name Comparison Operators
     /// \{
 
-    bool operator==(const std::string& other) const;
-    bool operator!=(const std::string& other) const;
+    bool operator==(const std::string& other) const noexcept;
+    bool operator!=(const std::string& other) const noexcept;
 
     /// \}
 
