@@ -5,7 +5,8 @@
 
 #include <cstddef>
 #include <cstdint>
-#include <ostream>
+
+#include <iosfwd>
 #include <string>
 #include <tuple>
 #include <vector>
@@ -51,7 +52,7 @@ struct Read
     std::string Model;
     bool FullLength = false;
 
-    size_t Length() const;
+    int32_t Length() const;
     std::string FullName() const;
 
     Read ClipTo(const int32_t begin, const int32_t end) const;
