@@ -15,18 +15,18 @@ namespace Utility {
 
 struct FileDeleter
 {
-    void operator()(std::FILE* fp) const;
+    void operator()(std::FILE* fp) const noexcept;
 };
 
 // For pointers originating from C 'malloc' (and friends), instead of 'new'
 struct FreeDeleter
 {
-    void operator()(void* p) const;
+    void operator()(void* p) const noexcept;
 
-    void operator()(const void* p) const;
+    void operator()(const void* p) const noexcept;
 };
 
 }  // namespace Utility
 }  // namespace PacBio
 
-#endif  // PBCOPPER_UTILITY_DELETERS_H
\ No newline at end of file
+#endif  // PBCOPPER_UTILITY_DELETERS_H
