@@ -6,27 +6,35 @@ export ENABLED_TESTS="true"
 export SHOULD_INSTALL="false"
 
 case "${GCC_VERSION}" in
-  RHEL)
+  next)
+    module load gcc/8.1.0
+    module load gtest
+    ;;
+
+  PA)
     module load gtest/gcc48
 
     # load SCL GCC
     source /opt/rh/devtoolset-6/enable
     ;;
 
-  next)
-    module load gcc/8.1.0
-    module load gtest
-    ;;
-
-  ICC)
+  ICC*)
     module load devtoolset/6
-    module load composer_xe/2017.4.196
+    module load composer_xe/${GCC_VERSION#ICC}
     module load gtest/gcc48
 
     CC="icc"
     CXX="icpc"
     ;;
 
+  clang)
+    module load gtest/gcc48
+
+    source /opt/rh/llvm-toolset-6.0/enable
+    CC="clang"
+    CXX="clang++"
+    ;;
+
   *)
     case "${bamboo_planRepository_branchName}-${BUILDTYPE:-release}-${ENABLED_UNITY_BUILD:-off}-${ENABLED_COVERAGE:-false}" in
       develop-release-off-false|master-release-off-false)
@@ -47,6 +55,12 @@ export CC="ccache ${CC:-gcc}"
 export CXX="ccache ${CXX:-g++}"
 export CCACHE_BASEDIR="${PWD}"
 
+if [[ ${GCC_VERSION} != ICC* ]]; then
+  # without -fno-sanitize-recover=all UBSAN failures won't abort the program
+  export CFLAGS="${CFLAGS} -fno-sanitize-recover=all"
+  export CXXFLAGS="${CXXFLAGS} -fno-sanitize-recover=all"
+fi
+
 if [[ -z ${bamboo_planRepository_branchName+x} ]]; then
   : #pass
 elif [[ ! -d /pbi/flash/bamboo/ccachedir ]]; then
