@@ -19,19 +19,6 @@ using PositionalArgumentTranslator = PacBio::CLI_v2::internal::PositionalArgumen
 namespace PacBio {
 namespace CLI_v2 {
 
-static_assert(std::is_copy_constructible<Interface>::value,
-              "Interface(const Interface&) is not = default");
-static_assert(std::is_copy_assignable<Interface>::value,
-              "Interface& operator=(const Interface&) is not = default");
-
-#ifndef __INTEL_COMPILER
-static_assert(std::is_nothrow_move_constructible<Interface>::value,
-              "Interface(Interface&&) is not = noexcept");
-static_assert(std::is_nothrow_move_assignable<Interface>::value ==
-                  std::is_nothrow_move_assignable<internal::InterfaceData>::value,
-              "");
-#endif
-
 Interface::Interface(std::string name, std::string description, std::string version)
     : data_{std::move(name),
             std::move(description),
@@ -229,6 +216,14 @@ const std::vector<PositionalArgumentData>& Interface::PositionalArguments() cons
     return data_.positionalArgs_;
 }
 
+void Interface::PrintVersion() const { data_.versionPrinter_(*this); }
+
+Interface& Interface::RegisterVersionPrinter(VersionPrinterCallback printer)
+{
+    data_.versionPrinter_ = printer;
+    return *this;
+}
+
 const boost::optional<internal::OptionData>& Interface::VerboseOption() const
 {
     return data_.verboseOption_;
