@@ -30,7 +30,7 @@ QualityValue::QualityValue(const uint8_t value)
 
 char QualityValue::Fastq() const { return static_cast<char>(value_ + 33); }
 
-QualityValue::operator uint8_t() const { return value_; }
+QualityValue::operator uint8_t() const noexcept { return value_; }
 
 QualityValue QualityValue::FromFastq(const char c) { return {static_cast<uint8_t>(c - 33)}; }
 
