@@ -4,6 +4,7 @@
 
 #include <algorithm>
 #include <cassert>
+#include <ostream>
 #include <type_traits>
 
 #include <boost/algorithm/string.hpp>
@@ -55,7 +56,7 @@ QualityValues::QualityValues(const QualityValues::const_iterator first,
     assign(first, last);
 }
 
-QualityValues& QualityValues::operator=(std::vector<QualityValue> quals)
+QualityValues& QualityValues::operator=(std::vector<QualityValue> quals) noexcept
 {
     std::vector<QualityValue>::operator=(std::move(quals));
     return *this;
@@ -103,12 +104,12 @@ std::string QualityValues::Fastq() const
     return result;
 }
 
-bool QualityValues::operator==(const std::string& fastq) const
+bool QualityValues::operator==(const std::string& fastq) const noexcept
 {
     return *this == QualityValues(fastq);
 }
 
-bool QualityValues::operator!=(const std::string& fastq) const
+bool QualityValues::operator!=(const std::string& fastq) const noexcept
 {
     return *this != QualityValues(fastq);
 }
