@@ -7,15 +7,15 @@
 namespace PacBio {
 namespace Utility {
 
-void FileDeleter::operator()(std::FILE* fp) const
+void FileDeleter::operator()(std::FILE* fp) const noexcept
 {
     if (fp) std::fclose(fp);
     fp = nullptr;
 }
 
-void FreeDeleter::operator()(void* p) const { std::free(p); }
+void FreeDeleter::operator()(void* p) const noexcept { std::free(p); }
 
-void FreeDeleter::operator()(const void* p) const { operator()(const_cast<void*>(p)); }
+void FreeDeleter::operator()(const void* p) const noexcept { operator()(const_cast<void*>(p)); }
 
 }  // namespace Utility
-}  // namespace PacBio
\ No newline at end of file
+}  // namespace PacBio
