@@ -1,18 +1,19 @@
-#include <gtest/gtest.h>
+#include <pbcopper/cli2/CLI.h>
 
-#include <fstream>
 #include <iostream>
 #include <sstream>
 #include <string>
 #include <tuple>
 #include <vector>
 
-#include <pbcopper/cli2/CLI.h>
+#include <gtest/gtest.h>
+
 #include <pbcopper/cli2/Option.h>
 #include <pbcopper/cli2/PositionalArgument.h>
 #include <pbcopper/cli2/Results.h>
 #include <pbcopper/cli2/internal/HelpMetrics.h>
 #include <pbcopper/cli2/internal/InterfaceHelpPrinter.h>
+#include <pbcopper/cli2/internal/MultiToolInterfaceHelpPrinter.h>
 #include <pbcopper/utility/OStreamRedirect.h>
 
 #include "PbcopperTestData.h"
@@ -720,68 +721,94 @@ TEST(CLI2_CLI, command_line_log_level_overrides_interface_configs)
     EXPECT_EQ(EXIT_SUCCESS, result);
 }
 
-// TEST(CLI2_CLI, throws_if_missing_required_number_of_pos_args)
-// {
-//     const PacBio::CLI_v2::PositionalArgument In {
-//     R"({
-//         "name" : "in",
-//         "description" : "Input file.",
-//         "type" : "file"
-//     })"
-//     };
+TEST(CLI2_CLI, can_use_custom_version_callback)
+{
+    const std::vector<std::string> args {
+        "frobber", "--version"
+    };
+    auto runner = [](const PacBio::CLI_v2::Results& results)
+    {
+        EXPECT_FALSE(results.Verbose());
+        return EXIT_SUCCESS;
+    };
+    auto versionPrinter = [](const PacBio::CLI_v2::Interface& i)
+    {
+        std::ignore = i;
+        std::cout << "Custom version printer";
+    };
 
-//     const PacBio::CLI_v2::PositionalArgument Out {
-//     R"({
-//         "name" : "out",
-//         "description" : "Output file.",
-//         "type" : "file"
-//     })"
-//     };
+    PacBio::CLI_v2::Interface i{"frobber", "Frob all the things.", "v3.1"};
+    i.RegisterVersionPrinter(versionPrinter);
 
-//     const PacBio::CLI_v2::PositionalArgument Report {
-//     R"({
-//         "name" : "report",
-//         "description" : "Report file.",
-//         "type" : "file"
-//     })"
-//     };
+    std::ostringstream s;
+    PacBio::Utility::CoutRedirect redirect{s.rdbuf()};
+    std::ignore = redirect;
 
-//     auto runner = [](const PacBio::CLI_v2::Results& results) {
-//         std::ignore = results;
-//         return EXIT_SUCCESS;
-//     };
+    const int result = PacBio::CLI_v2::Run(args, i, runner);
+    EXPECT_EQ("Custom version printer", s.str());
+    EXPECT_EQ(EXIT_SUCCESS, result);
+}
 
-//     PacBio::CLI_v2::Interface i {
-//         "frobber",
-//         "Frobb your files in a most delightful, nobbly way",
-//         "3.14"
-//     };
-//     i.AddPositionalArguments({In, Out, Report});
+TEST(CLI2_CLI, creates_alarm_for_all_exceptions_when_given_alarm_file_arg) {
 
-//     try {
-//         const std::vector<std::string> args {"frobber", "in.file"};
-//         const auto result = PacBio::CLI_v2::Run(args, i, runner);
+    const std::string alarmFilename{PacBio::PbcopperTestsConfig::Generated_Dir + "/std_exception_alarm.json"};
 
-//         std::ignore = result;
-//         ASSERT_FALSE("should not reach here");
-//     } catch (std::runtime_error& e) {
-//         const std::string msg{
-//             "[pbcopper] command line parser ERROR: requires 3 arguments, but 1 was provided\n"
-//         };
-//         EXPECT_EQ(msg, e.what());
-//     }
-//     try {
-//         const std::vector<std::string> args {"frobber", "in.file", "out.file"};
-//         const auto result = PacBio::CLI_v2::Run(args, i, runner);
+    const std::vector<std::string> args {"frobber", "--alarms", alarmFilename};
+    auto runner = [](const PacBio::CLI_v2::Results&)
+    {
+        throw std::runtime_error{"std exception from application"};
+        return 0;
+    };
 
-//         std::ignore = result;
-//         ASSERT_FALSE("should not reach here");
-//     } catch (std::runtime_error& e) {
-//         const std::string msg{
-//             "[pbcopper] command line parser ERROR: requires 3 arguments, but 2 were provided\n"
-//         };
-//         EXPECT_EQ(msg, e.what());
-//     }
-// }
+    std::ostringstream logOutput;
+    PacBio::Utility::CerrRedirect redirect{logOutput.rdbuf()};
+    std::ignore = redirect;
+
+    PacBio::CLI_v2::Interface i{"frobber", "Frob all the things.", "v3.1"};
+    const int result = PacBio::CLI_v2::Run(args, i, runner);
+    EXPECT_EQ(EXIT_FAILURE, result);
+
+    // check std::cerr logging
+    EXPECT_TRUE(logOutput.str().find("std exception from application") != std::string::npos);
+
+    // check alarm file
+    std::ifstream alarmFile{alarmFilename};
+    std::ostringstream alarmText;
+    alarmText << alarmFile.rdbuf();
+    EXPECT_TRUE(alarmText.str().find("std exception from application") != std::string::npos);
+}
+
+TEST(CLI2_CLI, multitoolinterface_supports_hidden_subtools)
+{
+    using namespace PacBio;
+
+    CLI_v2::MultiToolInterface i{"isoseq3", "De Novo Transcript Reconstruction", "3.1.2"};
+    i.AddTools({{"refine",    CLI_v2_CLITests::MakeRefineInterface(),    &CLI_v2_CLITests::RefineRunner, CLI_v2::ToolVisibility::HIDDEN},
+                {"cluster",   CLI_v2_CLITests::MakeClusterInterface(),   &CLI_v2_CLITests::ClusterRunner},
+                {"polish",    CLI_v2_CLITests::MakePolishInterface(),    &CLI_v2_CLITests::PolishRunner},
+                {"summarize", CLI_v2_CLITests::MakeSummarizeInterface(), &CLI_v2_CLITests::SummarizeRunner}});
+
+    // hidden from help
+    {
+        CLI_v2::internal::MultiToolInterfaceHelpPrinter help{i};
+        std::ostringstream out;
+        help.Print(out);
+        EXPECT_TRUE(out.str().find("refine") == std::string::npos);
+    }
+
+    // can run from CLI
+    {
+        const std::vector<std::string> args {
+        "isoseq3", "refine", "--test", "--count", "10"
+        };
+
+        std::ostringstream s;
+        Utility::CoutRedirect redirect{s.rdbuf()};
+        std::ignore = redirect;
+
+        const int result = CLI_v2::Run(args, i);
+        EXPECT_EQ(EXIT_SUCCESS, result);
+    }
+}
 
 // clang-format on
