@@ -1,12 +1,13 @@
 // Author: Derek Barnett
 
+#include <pbcopper/data/Read.h>
+
 #include <algorithm>
 
 #include <gtest/gtest.h>
 
 #include <pbcopper/data/Clipping.h>
 #include <pbcopper/data/MappedRead.h>
-#include <pbcopper/data/Read.h>
 #include <pbcopper/data/internal/ClippingImpl.h>
 
 using namespace PacBio::Data;
@@ -630,7 +631,7 @@ TEST(Data_Read, can_set_query_start_and_end_from_id)
     EXPECT_EQ(qEnd, read.QueryEnd);
 }
 
-TEST(Data_ReadId, can_set_movie_and_interval_from_read_name)
+TEST(Data_ReadId, can_create_from_subread_name)
 {
     const PacBio::Data::ReadId id{"m54001_160623_195125/553/3100_11230"};
     EXPECT_EQ("m54001_160623_195125", id.MovieName);
@@ -638,4 +639,12 @@ TEST(Data_ReadId, can_set_movie_and_interval_from_read_name)
     EXPECT_EQ(PacBio::Data::Interval(3100, 11230), *id.ZmwInterval);
 }
 
+TEST(Data_ReadId, can_create_from_ccs_read_name)
+{
+    const PacBio::Data::ReadId id{"m54001_160623_195125/553/ccs"};
+    EXPECT_EQ("m54001_160623_195125", id.MovieName);
+    EXPECT_EQ(553, id.HoleNumber);
+    EXPECT_FALSE(id.ZmwInterval.is_initialized());
+}
+
 // clang-format on
