@@ -1,7 +1,7 @@
-#include <gtest/gtest.h>
-
 #include <pbcopper/pbmer/Dbg.h>
 
+#include <gtest/gtest.h>
+
 TEST(Pbmer_Dbg, add_kmers_throws_if_kmer_too_big)
 {
     const PacBio::Pbmer::Parser parser{32};
@@ -50,45 +50,6 @@ TEST(Pbmer_Dbg, check_dump)
     EXPECT_EQ(1, 1);
 }
 
-TEST(Pbmer_Dbg, test_topo_three_kmers_add_many)
-{
-    const PacBio::Pbmer::Parser parser{3};
-    const std::string td1{"CATAG"};
-    std::vector<PacBio::Pbmer::DnaBit> m1 = parser.ParseDnaBit(td1);
-    std::vector<PacBio::Pbmer::BI> kmers_to_load;
-
-    for (auto& niby : m1) {
-
-        niby = niby.LexSmallerEq();
-
-        auto load = niby.DnaBit2Bin();
-        load |= 1;
-
-        kmers_to_load.emplace_back(load);
-    }
-
-    PacBio::Pbmer::Dbg dg{3, 1};
-    dg.AddKmers(kmers_to_load, 0);
-
-    EXPECT_EQ(dg.NNodes(), 3);
-
-    dg.BuildEdges();
-
-    std::string expected = R"(digraph DBGraph {
-    ATG [fillcolor=red, style="rounded,filled", shape=diamond]
-    CTA [fillcolor=red, style="rounded,filled", shape=diamond]
-    ATA [fillcolor=grey, style="rounded,filled", shape=ellipse]
-    ATG -> ATA;
-    CTA -> ATA;
-    ATA -> CTA;
-    ATA -> ATG;
-})";
-
-    std::string seen = dg.Graph2StringDot();
-    EXPECT_EQ(dg.ValidateEdges(), true);
-    EXPECT_EQ(seen, expected);
-}
-
 TEST(Pbmer_Dbg, test_topo_three_kmers)
 {
     const PacBio::Pbmer::Parser parser{3};
@@ -148,51 +109,6 @@ TEST(Pbmer_Dbg, test_topo_five_kmers)
     EXPECT_EQ(seen, expected);
 }
 
-TEST(Pbmer_Dbg, test_topo_five_kmers_add_many)
-{
-    const PacBio::Pbmer::Parser parser{3};
-    const std::string td1{"CATACCT"};
-    std::vector<PacBio::Pbmer::DnaBit> m1 = parser.ParseDnaBit(td1);
-
-    std::vector<PacBio::Pbmer::BI> kmers_to_load;
-
-    for (auto& niby : m1) {
-
-        niby = niby.LexSmallerEq();
-
-        auto load = niby.DnaBit2Bin();
-        load |= 1;
-
-        kmers_to_load.emplace_back(load);
-    }
-
-    PacBio::Pbmer::Dbg dg{3, 1};
-    dg.AddKmers(kmers_to_load, 0);
-
-    EXPECT_EQ(dg.NNodes(), 5);
-
-    dg.BuildEdges();
-
-    std::string expected = R"(digraph DBGraph {
-    ACC [fillcolor=grey, style="rounded,filled", shape=ellipse]
-    AGG [fillcolor=red, style="rounded,filled", shape=diamond]
-    GTA [fillcolor=red, style="rounded,filled", shape=diamond]
-    ATG [fillcolor=red, style="rounded,filled", shape=diamond]
-    ATA [fillcolor=grey, style="rounded,filled", shape=ellipse]
-    ACC -> AGG;
-    ACC -> GTA;
-    AGG -> ACC;
-    GTA -> ATA;
-    GTA -> ACC;
-    ATG -> ATA;
-    ATA -> GTA;
-    ATA -> ATG;
-})";
-
-    std::string seen = dg.Graph2StringDot();
-    EXPECT_EQ(seen, expected);
-}
-
 TEST(Pbmer_Dbg, test_topo_five_kmers_add_verifed_edges)
 {
     const PacBio::Pbmer::Parser parser{3};
@@ -298,6 +214,74 @@ TEST(Pbmer_Dbg, FrequencyFilterNodes_empty)
     EXPECT_EQ(dg.NNodes(), 0);
 }
 
+TEST(Pbmer_Dbg, FrequencyFilterNodes2_empty)
+{
+
+    const PacBio::Pbmer::Parser parser{7};
+    //SNV                         (X)
+    const std::string td1{"ATGGAAGTCGCGGAACAAATC"};
+    const std::string td2{"ATGGAAGTGGCGGAACAAATC"};
+
+    PacBio::Pbmer::Mers m1{parser.Parse(td1)};
+    PacBio::Pbmer::Mers m2{parser.Parse(td2)};
+
+    PacBio::Pbmer::Dbg dg{7, 2};
+
+    dg.AddKmers(m1, 1);
+    dg.AddKmers(m2, 2);
+
+    dg.BuildEdges();
+
+    dg.FrequencyFilterNodes2(10);
+    EXPECT_EQ(dg.NNodes(), 0);
+}
+
+TEST(Pbmer_Dbg, FrequencyFilterNodes2_gt1)
+{
+
+    const PacBio::Pbmer::Parser parser{7};
+    //SNV                         (X)
+    const std::string td1{"ATGGAAGTCGCGGAACAAATC"};
+    const std::string td2{"ATGGAAGTGGCGGAACAAATC"};
+
+    PacBio::Pbmer::Mers m1{parser.Parse(td1)};
+    PacBio::Pbmer::Mers m2{parser.Parse(td2)};
+
+    PacBio::Pbmer::Dbg dg{7, 2};
+
+    dg.AddKmers(m1, 1);
+    dg.AddKmers(m2, 2);
+
+    dg.BuildEdges();
+
+    dg.FrequencyFilterNodes2(0, true);
+    EXPECT_EQ(dg.NNodes(), 0);
+}
+
+TEST(Pbmer_Dbg, FrequencyFilterNodes2_gt1_lt2)
+{
+
+    const PacBio::Pbmer::Parser parser{7};
+    //SNV                         (X)
+    const std::string td1{"ATGGAAGTCGCGGAACAAATC"};
+    const std::string td2{"ATGGAAGTGGCGGAACAAATC"};
+
+    PacBio::Pbmer::Mers m1{parser.Parse(td1)};
+    PacBio::Pbmer::Mers m2{parser.Parse(td2)};
+
+    PacBio::Pbmer::Dbg dg{7, 2};
+
+    dg.AddKmers(m1, 1);
+    dg.AddKmers(m2, 2);
+
+    dg.BuildEdges();
+
+    dg.FrequencyFilterNodes2(1, true);
+    dg.FrequencyFilterNodes2(1, false);
+    // 22 nodes 8 of which span the bubble path;
+    EXPECT_EQ(dg.NNodes(), 14);
+}
+
 TEST(Pbmer_Dbg, FrequencyFilterNodes_one_left)
 {
 
@@ -338,7 +322,7 @@ TEST(Pbmer_Dbg, GetNBreadth_bubble_found)
     dg.AddKmers(m2, 2);
 
     dg.BuildEdges();
-    auto bubbles = dg.GetBubbles();
+    auto bubbles = dg.FindBubbles();
     EXPECT_EQ(bubbles.size(), 1);
 }
 
@@ -359,7 +343,7 @@ TEST(Pbmer_Dbg, GetNBreadth_node_count_correct)
     dg.AddKmers(m2, 2);
 
     dg.BuildEdges();
-    auto bubbles = dg.GetBubbles();
+    auto bubbles = dg.FindBubbles();
 
     EXPECT_EQ(dg.NNodes(), 15);
     EXPECT_EQ(bubbles.size(), 0);
@@ -382,7 +366,7 @@ TEST(Pbmer_Dbg, GetNBreadth_bubble_found_rc_first)
     dg.AddKmers(m2, 2);
 
     dg.BuildEdges();
-    auto bubbles = dg.GetBubbles();
+    auto bubbles = dg.FindBubbles();
 
     EXPECT_EQ(bubbles.size(), 1);
 }
@@ -404,12 +388,12 @@ TEST(Pbmer_Dbg, GetNBreadth_bubble_found_rc)
     dg.AddKmers(m2, 2);
 
     dg.BuildEdges();
-    auto bubbles = dg.GetBubbles();
+    auto bubbles = dg.FindBubbles();
 
     EXPECT_EQ(bubbles.size(), 1);
 }
 
-TEST(Pbmer_Dbg, GetBubbles_mismatch_found)
+TEST(Pbmer_Dbg, Bubbles_mismatch_found)
 {
     const PacBio::Pbmer::Parser parser{15};
     //mismatch                                        (X)
@@ -425,9 +409,12 @@ TEST(Pbmer_Dbg, GetBubbles_mismatch_found)
     dg.AddKmers(m2, 2);
 
     dg.BuildEdges();
-    auto bubbles = dg.GetBubbles();
-
+    auto bubbles = dg.FindBubbles();
     EXPECT_EQ(bubbles.size(), 1);
+    //reverse comp
+    EXPECT_EQ(bubbles[0].LSeq, "AAATTCGAATTCTACATTGGATTACTTTA");
+    //reverse comp
+    EXPECT_EQ(bubbles[0].RSeq, "AAATTCGAATTCTAAATTGGATTACTTTA");
 }
 /*
 This is de bruijn graph has a complicated topology.Leave as a stretch
@@ -438,7 +425,7 @@ This is de bruijn graph has a complicated topology.Leave as a stretch
     : TTCCAGTGCGGGAGG-- ----------CACTGCTAGCATAGCCGGTAATC(1949 - 1986)
 
 
-TEST(Dbg_GetBubbles, indel_found)
+TEST(Dbg_Bubbles, indel_found)
 {
     const PacBio::Pbmer::Parser parser{15};
     //del                                (X)
@@ -454,7 +441,7 @@ TEST(Dbg_GetBubbles, indel_found)
     dg.AddKmers(m2, 2);
 
     dg.BuildEdges();
-    auto bubbles = dg.GetBubbles();
+    auto bubbles = dg.FindBubbles();
     dg.WriteGraph("kmer_graph_indel.dot");
 
     // this is a failing test
@@ -463,7 +450,7 @@ TEST(Dbg_GetBubbles, indel_found)
 
     */
 
-TEST(Pbmer_Dbg, GetBubbles_indel_found2)
+TEST(Pbmer_Dbg, Bubbles_indel_found2)
 {
     const PacBio::Pbmer::Parser parser{15};
     //del                                  (X)
@@ -479,12 +466,12 @@ TEST(Pbmer_Dbg, GetBubbles_indel_found2)
     dg.AddKmers(m2, 2);
 
     dg.BuildEdges();
-    auto bubbles = dg.GetBubbles();
+    auto bubbles = dg.FindBubbles();
 
     EXPECT_EQ(bubbles.size(), 1);
 }
 
-TEST(Pbmer_Dbg, GetBubbles_no_bubble)
+TEST(Pbmer_Dbg, Bubbles_no_bubble)
 {
     const PacBio::Pbmer::Parser parser{7};
     //SNV                         (X)
@@ -501,7 +488,7 @@ TEST(Pbmer_Dbg, GetBubbles_no_bubble)
 
     dg.BuildEdges();
 
-    auto bubbles = dg.GetBubbles();
+    auto bubbles = dg.FindBubbles();
 
     EXPECT_EQ(bubbles.size(), 0);
 }
@@ -620,13 +607,13 @@ TEST(Pbmer_Dbg, SpurRemoval_spur_bubble_cleanup)
     dg.BuildEdges();
 
     auto spurCount = dg.RemoveSpurs(1);
-    auto bubbles = dg.GetBubbles();
+    auto bubbles = dg.FindBubbles();
 
     EXPECT_EQ(spurCount, 1);
     EXPECT_EQ(bubbles.size(), 1);
 }
 
-TEST(Pbmer_Dbg, GetBubbles_double_bubble_rc)
+TEST(Pbmer_Dbg, Bubbles_double_bubble_rc)
 {
     const std::string td1{
         "AGTCCGGCTTCGGAGCGGGATCAGGAGCGGTGGCCGCTGGGAATACCAATGGCCACAGCACCACCTCCAGTAGCAGCACTCATCTG"
@@ -649,12 +636,12 @@ TEST(Pbmer_Dbg, GetBubbles_double_bubble_rc)
 
     dg.BuildEdges();
 
-    auto bubbles = dg.GetBubbles();
+    auto bubbles = dg.FindBubbles();
 
     EXPECT_EQ(bubbles.size(), 2);
 }
 
-TEST(Pbmer_Dbg, GetBubbles_complex_snv)
+TEST(Pbmer_Dbg, Bubbles_complex_snv)
 {
     const std::string td1{"TGAACAAGTCACAAAAAAAAAAGATAATTTAAATGAAC"};
     const std::string td2{"TGAACAAGTCACAAAAAACAGAGATATTTAAAATGAAC"};
@@ -686,7 +673,7 @@ TEST(Pbmer_Dbg, GetBubbles_complex_snv)
 
     dg.BuildEdges();
 
-    auto bubbles = dg.GetBubbles();
+    auto bubbles = dg.FindBubbles();
 
     EXPECT_EQ(bubbles.size(), 1);
 }
